@@ -23,6 +23,16 @@ function test_blue_assistant_help() {
         "@assistant script list" \
         "@assistant script run" \
         \
+        "@hue" \
+        "@hue create_user" \
+        "@hue list" \
+        "@hue set" \
+        "@hue test" \
+        \
+        "@web" \
+        "@web crawl" \
+        "@web fetch" \
+        \
         "blue_assistant"; do
         abcli_eval ,$options \
             abcli_help $module
