@@ -30,11 +30,14 @@ def help_run(
     tokens: List[str],
     mono: bool,
 ) -> str:
-    options = xtra("download,dryrun,~upload", mono=mono)
+    options = xtra("~download,dryrun,~upload", mono=mono)
 
     script_options = "script=<script>"
 
-    args = ["--verbose 1"]
+    args = [
+        "[--test_mode 1]",
+        "[--verbose 1]",
+    ]
 
     return show_usage(
         [
